# finrich

Calculate enrichment of genomic regions with fine-mapping signals

## Installation

```sh
pip3 install finrich
```
or
```sh
pip3 install --user finrich
```

## Example
```
finrich --help
finrich finemap.bed regions.bed background.bed --permutations 1000 --processes 2
```
